@@ -27,15 +27,11 @@
 // |                                                                           |
 // +---------------------------------------------------------------------------|
 
-if (strpos(strtolower($_SERVER['PHP_SELF']), strtolower(__FILE__)) !== FALSE) {
-    die ('This file can not be used on its own.');
-}
-
 global $LANG32;
 
 $LANG_XMLSMAP = array(
-    'plugin'            => 'XMLSitemap',
-    'admin'		        => 'XMLSitemap Admin',
+    'plugin' => 'XMLSitemap',
+    'admin' => 'XMLSitemap Admin'
 );
 
 // Localization of the Admin Configuration UI
@@ -45,37 +41,37 @@ $LANG_configsections['xmlsitemap'] = array(
 );
 
 $LANG_confignames['xmlsitemap'] = array(
-    'sitemap_file'        => 'Nom du fichier Sitemap',
+    'sitemap_file' => 'Nom du fichier Sitemap',
     'mobile_sitemap_file' => 'Nom du fichier Sitemap Mobile',
-    'types'               => 'Contenu du sitemap',
-    'exclude'             => 'Plugins  exclure du sitemap',
-    'priorities'          => '',
-    'frequencies'         => '',
+    'types' => 'Contenu du sitemap',
+    'exclude' => 'Plugins  exclure du sitemap',
+    'priorities' => '',
+    'frequencies' => ''
 );
 
 $LANG_configsubgroups['xmlsitemap'] = array(
-    'sg_main' => 'Paramtres principaux',
+    'sg_main' => 'Paramtres principaux'
 );
 
 $LANG_tab['xmlsitemap'] = array(
     'tab_main' => 'Paramtres principaux XMLSitemap',
-    'tab_pri'  => 'Priorit',
-    'tab_freq' => 'Frquence de mise  jour',
+    'tab_pri' => 'Priorit',
+    'tab_freq' => 'Frquence de mise  jour'
 );
 
 $LANG_fs['xmlsitemap'] = array(
     'fs_main' => 'XMLSitemap paramtres principaux',
-    'fs_pri'  => 'Priorit (defaut = 0.5, basse = 0.0, haute = 1.0)',
-    'fs_freq' => 'Frquence de mise  jour',
+    'fs_pri' => 'Priorit (defaut = 0.5, basse = 0.0, haute = 1.0)',
+    'fs_freq' => 'Frquence de mise  jour'
 );
 
 // Note: entries 0, 1, 9, and 12 are the same as in $LANG_configselects['Core']
 $LANG_configselects['xmlsitemap'] = array(
     0 => array('Vrai' => 1, 'Faux' => 0),
-    1 => array('Vrai' => TRUE, 'Faux' => FALSE),
+    1 => array('Vrai' => true, 'Faux' => false),
     9 => array('Tranfrer  la page' => 'item', 'Afficher la liste' => 'list', 'Afficher page d\'accueil' => 'home', 'Afficher page d\'administration' => 'admin'),
     12 => array('Pas d\'accs' => 0, 'Lecture seule' => 2, 'Lecture Ecriture' => 3),
-    20 => array('toujours' => 'always', 'Toutes les heures' => 'hourly', 'Quotidienne' => 'daily', 'Hebdomadaire' => 'weekly', 'mensuelle' => 'monthly', 'annuelle' => 'yearly', 'jamais' => 'never'),
+    20 => array('toujours' => 'always', 'Toutes les heures' => 'hourly', 'Quotidienne' => 'daily', 'Hebdomadaire' => 'weekly', 'mensuelle' => 'monthly', 'annuelle' => 'yearly', 'jamais' => 'never')
 );
 
 ?>
