@@ -2,13 +2,13 @@
 
 /* Reminder: always indent with 4 spaces (no tabs). */
 // +---------------------------------------------------------------------------+
-// | Geeklog 1.6                                                               |
+// | Geeklog 1.8                                                               |
 // +---------------------------------------------------------------------------+
 // | story.php                                                                 |
 // |                                                                           |
 // | Geeklog story administration page.                                        |
 // +---------------------------------------------------------------------------+
-// | Copyright (C) 2000-2010 by the following authors:                         |
+// | Copyright (C) 2000-2011 by the following authors:                         |
 // |                                                                           |
 // | Authors: Tony Bibbs        - tony AT tonybibbs DOT com                    |
 // |          Mark Limburg      - mlimburg AT users DOT sourceforge DOT net    |
@@ -62,9 +62,8 @@ $_STORY_VERBOSE = false;
 $display = '';
 
 if (!SEC_hasRights('story.edit')) {
-    $display .= COM_siteHeader('menu', $MESSAGE[30])
-             . COM_showMessageText($MESSAGE[29], $MESSAGE[30])
-             . COM_siteFooter();
+    $display .= COM_showMessageText($MESSAGE[29], $MESSAGE[30]);
+    $display = COM_createHTMLDocument($display, array('pagetitle' => $MESSAGE[30]));
     COM_accessLog("User {$_USER['username']} tried to illegally access the story administration screen.");
     COM_output($display);
     exit;
@@ -120,49 +119,44 @@ function liststories($current_topic = '')
     $retval = '';
 
     if (empty($current_topic)) {
-        $current_topic = $LANG09[9];
+        $current_topic = TOPIC_ALL_OPTION;
     }
 
-    if ($current_topic == $LANG09[9]) { // "All"
-        $excludetopics = '';
-        $seltopics = '';
-        $topicsql = "SELECT tid,topic FROM {$_TABLES['topics']}"
-                  . COM_getPermSQL ();
-        $tresult = DB_query($topicsql);
-        $trows = DB_numRows($tresult);
-        if ($trows > 0) {
-            $exclude = array();
-            for ($i = 0; $i < $trows; $i++)  {
-                $T = DB_fetchArray($tresult);
-                $exclude[] = $T['tid'];
-                $seltopics .= '<option value="' . $T['tid'] . '"';
-                if ($current_topic == $T['tid']) {
-                    $seltopics .= ' selected="selected"';
-                }
-                $seltopics .= '>' . $T['topic'] . '</option>' . LB;
-            }
-            $excludetopics = " (tid IN ('" . implode( "','", $exclude ) . "')) ";
-        } else {
+    $seltopics = TOPIC_getTopicListSelect($current_topic, 2);
+    if (empty($seltopics)) {
+        $retval .= COM_showMessage(101);
+        return $retval;
+    }    
+    if ($current_topic == TOPIC_ALL_OPTION) {
+        // Retrieve list of inherited topics
+        // $tid_list = TOPIC_getChildList(TOPIC_ROOT);
+        
+        // Retrieve list of all topics user has access to (did not do inherit way since may not see all stories has access too)
+        $tid_list = TOPIC_getList(0, true, false);
+            
+        if (empty($tid_list)) {
             $retval .= COM_showMessage(101);
             return $retval;
         }
+        $excludetopics = " (tid IN ('" . implode( "','", $tid_list ) . "')) ";
     } else {
-        $excludetopics = " tid = '$current_topic' ";
+        // Retrieve list of inherited topics
+        $tid_list = TOPIC_getChildList($current_topic);
+        
+        // Get list of blocks to display (except for dynamic). This includes blocks for all topics, and child blocks that are inherited
+        $excludetopics = " (ta.tid IN({$tid_list}) AND (ta.inherit = 1 OR (ta.inherit = 0 AND ta.tid = '{$current_topic}')))";        
+        /*
         $seltopics = COM_topicList('tid,topic', $current_topic, 1, true);
         if (empty($seltopics)) {
             $retval .= COM_showMessage(101);
             return $retval;
         }
+        */
     }
 
-    $alltopics = '<option value="' .$LANG09[9]. '"';
-    if ($current_topic == $LANG09[9]) {
-        $alltopics .= ' selected="selected"';
-    }
-    $alltopics .= '>' .$LANG09[9]. '</option>' . LB;
     $filter = $LANG_ADMIN['topic']
         . ': <select name="tid" style="width: 125px" onchange="this.form.submit()">'
-        . $alltopics . $seltopics . '</select>';
+        . $seltopics . '</select>';
 
     $header_arr = array(
         array('text' => $LANG_ADMIN['edit'], 'field' => 'edit', 'sort' => false),
@@ -177,7 +171,7 @@ function liststories($current_topic = '')
         $header_arr[] = array('text' => $LANG24[7], 'field' => 'username', 'sort' => true); // author
     }
     $header_arr[] = array('text' => $LANG24[15], 'field' => 'unixdate', 'sort' => true); // date
-    $header_arr[] = array('text' => $LANG_ADMIN['topic'], 'field' => 'tid', 'sort' => true);
+    $header_arr[] = array('text' => $LANG_ADMIN['topic'], 'field' => 'topic_ids', 'sort' => true);
     $header_arr[] = array('text' => $LANG24[32], 'field' => 'featured', 'sort' => true);
 
     if (SEC_hasRights ('story.ping') && ($_CONF['trackback_enabled'] ||
@@ -210,7 +204,8 @@ function liststories($current_topic = '')
 
     $sql = "SELECT {$_TABLES['stories']}.*, {$_TABLES['users']}.username, {$_TABLES['users']}.fullname, "
           ."UNIX_TIMESTAMP(date) AS unixdate  FROM {$_TABLES['stories']} "
-          ."LEFT JOIN {$_TABLES['users']} ON {$_TABLES['stories']}.uid={$_TABLES['users']}.uid "
+          ."LEFT JOIN {$_TABLES['users']} ON {$_TABLES['stories']}.uid={$_TABLES['users']}.uid " 
+          ."LEFT JOIN {$_TABLES['topic_assignments']} ta ON ta.type = 'article' AND ta.id = sid "
           ."WHERE 1=1 ";
 
     if (!empty ($excludetopics)) {
@@ -219,6 +214,7 @@ function liststories($current_topic = '')
     $query_arr = array(
         'table' => 'stories',
         'sql' => $sql,
+        'query_group' => "sid,{$_TABLES['users']}.username,{$_TABLES['users']}.fullname",
         'query_fields' => array('title', 'introtext', 'bodytext', 'sid', 'tid'),
         'default_filter' => $excludetopics . COM_getPermSQL('AND')
     );
@@ -238,14 +234,13 @@ function liststories($current_topic = '')
 * @param    string      $sid            ID of story to edit
 * @param    string      $mode           'preview', 'edit', 'editsubmission', 'clone'
 * @param    string      $errormsg       a message to display on top of the page
-* @param    string      $currenttopic   topic selection for drop-down menu
 * @return   string      HTML for story editor
 *
 */
-function storyeditor($sid = '', $mode = '', $errormsg = '', $currenttopic = '')
+function storyeditor($sid = '', $mode = '', $errormsg = '')
 {
     global $_CONF, $_TABLES, $_USER, $LANG24, $LANG_ACCESS, $LANG_ADMIN,
-           $MESSAGE, $_SCRIPTS;
+           $MESSAGE, $_SCRIPTS, $LANG_DIRECTION, $LANG_MONTH, $LANG_WEEK;
 
     $display = '';
 
@@ -253,21 +248,8 @@ function storyeditor($sid = '', $mode = '', $errormsg = '', $currenttopic = '')
         $_CONF['hour_mode'] = 12;
     }
 
-    if (!empty ($errormsg)) {
-        $display .= COM_startBlock($LANG24[25], '',
-                            COM_getBlockTemplate ('_msg_block', 'header'));
-        $display .= $errormsg;
-        $display .= COM_endBlock (COM_getBlockTemplate ('_msg_block', 'footer'));
-    }
-
-    if (!empty ($currenttopic)) {
-        $allowed = DB_getItem ($_TABLES['topics'], 'tid',
-                                "tid = '" . addslashes ($currenttopic) . "'" .
-                                COM_getTopicSql ('AND'));
-
-        if ($allowed != $currenttopic) {
-            $currenttopic = '';
-        }
+    if (!empty($errormsg)) {
+        $display .= COM_showMessageText($errormsg, $LANG24[25]);
     }
 
     $story = new Story();
@@ -283,36 +265,45 @@ function storyeditor($sid = '', $mode = '', $errormsg = '', $currenttopic = '')
             }
         }
         $result = $story->loadFromArgsArray($_POST);
+
+        // in preview mode, we now need to re-insert the images
+        if ($_CONF['maximagesperarticle'] > 0) {
+            $errors = $story->insertImages();
+            if (count($errors) > 0) {
+                $msg = $LANG24[55] . LB . '<ul>' . LB;
+                foreach ($errors as $err) {
+                    $msg .= '<li>' . $err . '</li>' . LB;
+                }
+                $msg .= '</ul>' . LB;
+                $display .= COM_showMessageText($msg, $LANG24[54]);
+            }
+        }
     } else {
         $result = $story->loadFromDatabase($sid, $mode);
     }
 
-    if( ($result == STORY_PERMISSION_DENIED) || ($result == STORY_NO_ACCESS_PARAMS) )
-    {
-        $display .= COM_startBlock($LANG_ACCESS['accessdenied'], '',
-                                COM_getBlockTemplate ('_msg_block', 'header'));
-        $display .= $LANG24[42];
-        $display .= COM_endBlock(COM_getBlockTemplate ('_msg_block', 'footer'));
+    if (($result == STORY_PERMISSION_DENIED) ||
+            ($result == STORY_NO_ACCESS_PARAMS)) {
+        $display .= COM_showMessageText($LANG24[42],
+                                        $LANG_ACCESS['accessdenied']);
         COM_accessLog("User {$_USER['username']} tried to illegally access story $sid.");
         return $display;
-    } elseif( ($result == STORY_EDIT_DENIED) || ($result == STORY_EXISTING_NO_EDIT_PERMISSION) ) {
-        $display .= COM_startBlock($LANG_ACCESS['accessdenied'], '',
-                                COM_getBlockTemplate ('_msg_block', 'header'));
-        $display .= $LANG24[41];
-        $display .= COM_endBlock (COM_getBlockTemplate ('_msg_block', 'footer'));
+    } elseif (($result == STORY_EDIT_DENIED) ||
+            ($result == STORY_EXISTING_NO_EDIT_PERMISSION)) {
+        $display .= COM_showMessageText($LANG24[41],
+                                        $LANG_ACCESS['accessdenied']);
         $display .= STORY_renderArticle ($story, 'p');
         COM_accessLog("User {$_USER['username']} tried to illegally edit story $sid.");
         return $display;
-    } elseif( $result == STORY_INVALID_SID ) {
-        if( $mode == 'editsubmission' )
-        {
+    } elseif ($result == STORY_INVALID_SID) {
+        if ($mode == 'editsubmission') {
             // that submission doesn't seem to be there any more (may have been
             // handled by another Admin) - take us back to the moderation page
-            return COM_refresh( $_CONF['site_admin_url'] . '/moderation.php' );
+            return COM_refresh($_CONF['site_admin_url'] . '/moderation.php');
         } else {
-            return COM_refresh( $_CONF['site_admin_url'] . '/story.php' );
+            return COM_refresh($_CONF['site_admin_url'] . '/story.php');
         }
-    } elseif( $result == STORY_DUPLICATE_SID) {
+    } elseif ($result == STORY_DUPLICATE_SID) {
         $display .= COM_showMessageText($LANG24[24]);
     }
 
@@ -568,19 +559,19 @@ function storyeditor($sid = '', $mode = '', $errormsg = '', $currenttopic = '')
         $story_templates->set_var('hide_meta', ' style="display:none;"');
     }
     $story_templates->set_var('lang_topic', $LANG_ADMIN['topic']);
-    if(empty($currenttopic) && ($story->EditElements('tid') == '')) {
-        $story->setTid(DB_getItem($_TABLES['topics'], 'tid',
-                                  'is_default = 1' . COM_getPermSQL('AND')));
-    } elseif ($story->EditElements('tid') == '') {
-        $story->setTid($currenttopic);
+    
+    if ($mode == 'preview') {
+        $tlist = TOPIC_getTopicSelectionControl('article', '', false, true, true);
+    } else {        
+        $tlist = TOPIC_getTopicSelectionControl('article', $oldsid, false, true, true);
     }
-
-    $tlist = COM_topicList('tid,topic', $story->EditElements('tid'), 1, true);
+    
     if (empty($tlist)) {
         $display .= COM_showMessage(101);
         return $display;
     }
-    $story_templates->set_var('topic_options', $tlist);
+    $story_templates->set_var('topic_selection', $tlist);
+
     $story_templates->set_var('lang_show_topic_icon', $LANG24[56]);
     if ($story->EditElements('show_topic_icon') == 1) {
         $story_templates->set_var('show_topic_icon_checked', 'checked="checked"');
@@ -682,7 +673,13 @@ function storyeditor($sid = '', $mode = '', $errormsg = '', $currenttopic = '')
     $story_templates->set_var('lang_publishoptions',$LANG24[76]);
     $story_templates->set_var('noscript', COM_getNoScript(false, $LANG24[77], sprintf($LANG24[78],$_CONF['site_admin_url'], $sid)));
     
-    $post_options = COM_optionList($_TABLES['postmodes'],'code,name',$story->EditElements('postmode'));
+    $postmode = $story->EditElements('postmode');
+    if ($_CONF['advanced_editor'] && $_USER['advanced_editor']) {
+        if ($story->EditElements('advanced_editor_mode') == 1 OR $story->EditElements('postmode') == 'adveditor') {
+            $postmode = '';
+        }
+    }
+    $post_options = COM_optionList($_TABLES['postmodes'],'code,name',$postmode);
 
     // If Advanced Mode - add post option and set default if editing story created with Advanced Editor
     if ($_CONF['advanced_editor'] && $_USER['advanced_editor']) {
@@ -734,85 +731,35 @@ function storyeditor($sid = '', $mode = '', $errormsg = '', $currenttopic = '')
         }
         $fileinputs .= $LANG24[28] . '<br' . XHTML . '>';
     }
-    
-    // *****************************************    
-    // Add JavaScript
-    if (!$advanced_editormode) {
-        $js = '<script type="text/javascript">
-        //<![CDATA[
-        function enablearchive(obj) {
-            var f = obj.form;           // all elements have their parent form in "form"
-            var disable = obj.checked;  // Disable when checked
-            if (f.elements["archiveflag"].checked==true && f.elements["storycode11"].checked==false) {
-                f.elements["storycode10"].checked=true;
-            }
-            f.elements["storycode10"].disabled=!disable;
-            f.elements["storycode11"].disabled=!disable;
-            f.elements["expire_month"].disabled=!disable;
-            f.elements["expire_day"].disabled=!disable;
-            f.elements["expire_year"].disabled=!disable;
-            f.elements["expire_hour"].disabled=!disable;
-            f.elements["expire_minute"].disabled=!disable;
-            f.elements["expire_ampm"].disabled=!disable;
-        }
-            
-            function enablecmtclose(obj) {
-            var f = obj.form;           // all elements have their parent form in "form"
-            var disable = obj.checked;  // Disable when checked
-        
-            f.elements["cmt_close_month"].disabled=!disable;
-            f.elements["cmt_close_day"].disabled=!disable;
-            f.elements["cmt_close_year"].disabled=!disable;
-            f.elements["cmt_close_hour"].disabled=!disable;
-            f.elements["cmt_close_minute"].disabled=!disable;
-            f.elements["cmt_close_ampm"].disabled=!disable;
-            
-        }
-        //]]>
-        </script>' . LB;
-    } else {
-        $js = '<script type="text/javascript">
-            // Setup editor path for FCKeditor JS Functions
-            geeklogEditorBasePath = "' . $_CONF['site_url'] . '/fckeditor/";
-        </script>' . LB;
 
-        $js .= '<!-- Hide the Advanced Editor as Javascript is required. If JS is enabled then the JS below will un-hide it -->
-        <script type="text/javascript">
-            document.getElementById("advanced_editor").style.display=""
-        </script>';     
-        
-        $_SCRIPTS->setJavaScriptFile('advanced_editor', '/javascript/advanced_editor.js');
-        $_SCRIPTS->setJavaScriptFile('storyeditor_fckeditor', '/javascript/storyeditor_fckeditor.js');        
+    // Add JavaScript
+    $_SCRIPTS->setJavaScriptFile('story_editor', '/javascript/story_editor.js');
+
+    // Loads jQuery UI datepicker
+    $_SCRIPTS->setJavaScriptLibrary('jquery.ui.datepicker');
+    $_SCRIPTS->setJavaScriptLibrary('jquery-ui-i18n');
+    $_SCRIPTS->setJavaScriptFile('datepicker', '/javascript/datepicker.js');
+
+    $langCode = COM_getLangIso639Code();
+    $toolTip  = 'Click and select a date';	// Should be translated
+    $imgUrl   = $_CONF['site_url'] . '/images/calendar.png';
+
+    $_SCRIPTS->setJavaScript(
+        "jQuery(function () {"
+        . "  geeklog.datepicker.set('publish', '{$langCode}', '{$toolTip}', '{$imgUrl}');"
+        . "  geeklog.datepicker.set('expire', '{$langCode}', '{$toolTip}', '{$imgUrl}');"
+        . "  geeklog.datepicker.set('cmt_close', '{$langCode}', '{$toolTip}', '{$imgUrl}');"
+        . "});", TRUE, TRUE
+    );
+
+    if ($advanced_editormode) {
+        $_SCRIPTS->setJavaScriptFile('fckeditor','/fckeditor/fckeditor.js');
+        // Hide the Advanced Editor as Javascript is required. If JS is enabled then the JS below will un-hide it
+        $js = 'document.getElementById("advanced_editor").style.display="";';
+        $_SCRIPTS->setJavaScript($js, true);
+        $_SCRIPTS->setJavaScriptFile('storyeditor_fckeditor', '/javascript/storyeditor_fckeditor.js');
     }
     
-    $js .= '<script type="text/javascript">
-    <!-- This code will only be executed by a browser that supports Javascript -->
-    var jstest = ' . $js_showarchivedisabled . ';
-    var jstest2 = ' . $js_showcmtclosedisabled . ';
-    if (jstest) {
-        document.frmstory.expire_month.disabled=true;
-        document.frmstory.expire_day.disabled=true;
-        document.frmstory.expire_year.disabled=true;
-        document.frmstory.expire_hour.disabled=true;
-        document.frmstory.expire_minute.disabled=true;
-        document.frmstory.expire_ampm.disabled=true;
-        document.frmstory.storycode10.disabled=true;
-        document.frmstory.storycode11.disabled=true;
-    }
-    if (jstest2) {
-        document.frmstory.cmt_close_month.disabled=true;
-        document.frmstory.cmt_close_day.disabled=true;
-        document.frmstory.cmt_close_year.disabled=true;
-        document.frmstory.cmt_close_hour.disabled=true;
-        document.frmstory.cmt_close_minute.disabled=true;
-        document.frmstory.cmt_close_ampm.disabled=true;
-    }
-    </script>';    
-    
-    $_SCRIPTS->setJavaScript($js);
-    
-    // *****************************************
-    
     $story_templates->set_var('saved_images', $saved_images);
     $story_templates->set_var('image_form_elements', $fileinputs);
     $story_templates->set_var('lang_hits', $LANG24[18]);
@@ -916,6 +863,7 @@ if (isset($_REQUEST['editopt'])){
     }
 }
 
+
 $display = '';
 if (($mode == $LANG_ADMIN['delete']) && !empty ($LANG_ADMIN['delete'])) {
     $sid = COM_applyFilter ($_POST['sid']);
@@ -932,6 +880,9 @@ if (($mode == $LANG_ADMIN['delete']) && !empty ($LANG_ADMIN['delete'])) {
             COM_accessLog ("User {$_USER['username']} tried to illegally delete story submission $sid.");
             echo COM_refresh ($_CONF['site_admin_url'] . '/index.php');
         } else if (SEC_checkToken()) {
+            // Delete Topic Assignments for this submission
+            TOPIC_deleteTopicAssignments('article', $sid);
+            
             DB_delete ($_TABLES['storysubmission'], 'sid', $sid,
                        $_CONF['site_admin_url'] . '/moderation.php');
         } else {
@@ -945,27 +896,20 @@ if (($mode == $LANG_ADMIN['delete']) && !empty ($LANG_ADMIN['delete'])) {
         echo COM_refresh ($_CONF['site_admin_url'] . '/index.php');
     }
 } else if (($mode == $LANG_ADMIN['preview']) && !empty ($LANG_ADMIN['preview'])) {
-    $display .= COM_siteHeader('menu', $LANG24[5]);
     $display .= storyeditor(COM_applyFilter($_POST['sid']), 'preview', '', '');
-    $display .= COM_siteFooter();
+    $display = COM_createHTMLDocument($display, array('pagetitle' => $LANG24[5]));
     COM_output($display);
 } elseif (($mode == 'edit') || ($mode == 'clone')) {
-    $display .= COM_siteHeader('menu', $LANG24[5]);
     $sid = '';
     if (isset ($_GET['sid'])) {
         $sid = COM_applyFilter ($_GET['sid']);
     }
-    $topic = '';
-    if (isset ($_GET['topic'])) {
-        $topic = COM_applyFilter ($_GET['topic']);
-    }
-    $display .= storyeditor($sid, $mode, '', $topic);
-    $display .= COM_siteFooter();
+    $display .= storyeditor($sid, $mode, '');
+    $display = COM_createHTMLDocument($display, array('pagetitle' => $LANG24[5]));
     COM_output($display);
 } else if ($mode == 'editsubmission') {
-    $display .= COM_siteHeader('menu', $LANG24[5]);
     $display .= storyeditor (COM_applyFilter ($_GET['id']), $mode);
-    $display .= COM_siteFooter();
+    $display = COM_createHTMLDocument($display, array('pagetitle' => $LANG24[5]));
     COM_output($display);
 } else if (($mode == $LANG_ADMIN['save']) && !empty ($LANG_ADMIN['save']) && SEC_checkToken()) {
     submitstory ();
@@ -986,10 +930,9 @@ if (($mode == $LANG_ADMIN['delete']) && !empty ($LANG_ADMIN['delete'])) {
                 $current_topic = COM_applyFilter($_POST['tid']);
             }
         }
-        $display .= COM_siteHeader('menu', $LANG24[22]);
         $display .= COM_showMessageFromParameter();
         $display .= liststories($current_topic);
-        $display .= COM_siteFooter();
+        $display = COM_createHTMLDocument($display, array('pagetitle' => $LANG24[22]));
     }
     COM_output($display);
 }
