@@ -8,7 +8,7 @@
 // |                                                                           |
 // | Geeklog calendarjp plugin                                                 |
 // +---------------------------------------------------------------------------+
-// | Copyright (C) 2008-2010 by dengen - taharaxp AT gmail DOT com             |
+// | Copyright (C) 2008-2012 by dengen - taharaxp AT gmail DOT com             |
 // |                                                                           |
 // | Calendarjp plugin is based on prior work by:                              |
 // | Authors: Tony Bibbs        - tony AT tonybibbs DOT com                    |
@@ -49,9 +49,8 @@ $display = '';
 
 if (COM_isAnonUser() &&
     (($_CONF['loginrequired'] == 1) || ($_CAJP_CONF['calendarloginrequired'] == 1))) {
-    $display .= COM_siteHeader('menu', $LANG_CALJP_1[41]);
     $display .= SEC_loginRequiredForm();
-    $display .= COM_siteFooter();
+    $display = COM_createHTMLDocument($display, array('pagetitle' => $LANG_CALJP_1[41]));
     COM_output($display);
     exit;
 }
@@ -395,9 +394,9 @@ if ($mode != 'personal' && $mode != 'quickadd') {
 }
 
 if ($mode == 'personal') {
-    $display .= COM_siteHeader ('menu', $LANG_CALJP_1[42]);
+    $pagetitle = $LANG_CALJP_1[42];
 } else {
-    $display .= COM_siteHeader ('menu', $LANG_CALJP_1[41]);
+    $pagetitle = $LANG_CALJP_1[41];
 }
 
 // Set mode back to master if user refreshes screen after their session expires
@@ -409,7 +408,7 @@ if ($mode == 'personal' AND $_CAJP_CONF['personalcalendars'] == 0) {
     // User is trying to use the personal calendar feature even though it isn't
     // turned on.
     $display .= $LANG_CALJP_2[37];
-    $display .= COM_siteFooter();
+    $display = COM_createHTMLDocument($display, array('pagetitle' => $pagetitle));
     COM_output($display);
     exit;
 }
@@ -505,15 +504,11 @@ $ja = ($_CONF['language'] == 'japanese_utf-8');
 
 switch ($view) {
 case 'day':
-    $cal_templates = new Template($_CONF['path'] . 'plugins/calendarjp/templates/dayview');
+    $cal_templates = COM_newTemplate($_CONF['path'] . 'plugins/calendarjp/templates/dayview');
     $cal_templates->set_file(array('column'=>'column.thtml',
                                    'event'=>'singleevent.thtml',
                                    'dayview'=>'dayview.thtml',
                                    'quickadd'=>'quickaddform' . ($ja ? '_ja' : '') . '.thtml'));
-    $cal_templates->set_var ( 'xhtml', XHTML );
-    $cal_templates->set_var ('site_url', $_CONF['site_url']);
-    $cal_templates->set_var ('site_admin_url', $_CONF['site_admin_url']);
-    $cal_templates->set_var ('layout_url', $_CONF['layout_url']);
     $cal_templates->set_var('mode', $mode);
     $cal_templates->set_var('lang_day', $LANG_CALJP_2[39]);
     $cal_templates->set_var('lang_week', $LANG_CALJP_2[40]);
@@ -616,7 +611,6 @@ case 'day':
         $numevents = $hourcols[$i];
         if ($numevents > 0) {
             // $colsleft = $maxcols;
-            $cal_templates->set_var ('layout_url', $_CONF['path'] . 'plugins/calendarjp/templates/');
             for ($j = 1; $j <= $numevents; $j++) {
                 $A = current ($thedata);
                 $cal_templates->set_var ('event_time',
@@ -671,18 +665,14 @@ case 'day':
 // Added ---------<
     
     $display .= $cal_templates->parse('output', 'dayview');
-    $display .= COM_siteFooter();
+    $display = COM_createHTMLDocument($display, array('pagetitle' => $pagetitle));
     break;
 
 case 'week':
-    $cal_templates = new Template($_CONF['path'] . 'plugins/calendarjp/templates');
+    $cal_templates = COM_newTemplate($_CONF['path'] . 'plugins/calendarjp/templates');
     $cal_templates->set_file(array('week'=>'weekview/weekview.thtml',
                                    'events'=>'weekview/events.thtml',
                                    'quickadd'=>'dayview/quickaddform' . ($ja ? '_ja' : '') . '.thtml'));
-    $cal_templates->set_var ( 'xhtml', XHTML );
-    $cal_templates->set_var ('site_url', $_CONF['site_url']);
-    $cal_templates->set_var ('site_admin_url', $_CONF['site_admin_url']);
-    $cal_templates->set_var ('layout_url', $_CONF['layout_url']);
     $cal_templates->set_var('mode', $mode);
     $cal_templates->set_var('lang_week', $LANG_CALJP_2[27]);
     if ($mode == 'personal') {
@@ -735,7 +725,7 @@ case 'week':
             $eday = getPrettyDateNum(strftime ('%d', $time_day7));
             $end_mname = getPrettyDateNum(strftime ('%m', $time_day7));
             $end_ynum = strftime ('%Y', $time_day7);
-            $date_range = $start_mname . ' ' . getPrettyDateNum(strftime ('%d', $time_day1)) . '日';
+            $date_range = $start_mname . '月 ' . getPrettyDateNum(strftime ('%d', $time_day1)) . '日';
         } else {
             $start_mname = getPrettyDateNum(strftime ('%m', mktime (0, 0, 0, $month, $day, $year)));
             $time_day6 = mktime (0, 0, 0, $month, $day + 6, $year);
@@ -889,12 +879,12 @@ case 'week':
     }
 
     $display .= $cal_templates->parse('output','week');
-    $display .= COM_siteFooter();
+    $display = COM_createHTMLDocument($display, array('pagetitle' => $pagetitle));
     break;
 
 case 'addentry':
     $display .= plugin_submit_calendarjp($mode);
-    $display .= COM_siteFooter();
+    $display = COM_createHTMLDocument($display, array('pagetitle' => $pagetitle));
     break;
 
 case 'savepersonal':
@@ -908,7 +898,7 @@ case 'savepersonal':
 default: // month view
 // Load templates
 
-$cal_templates = new Template($_CONF['path'] . 'plugins/calendarjp/templates');
+$cal_templates = COM_newTemplate($_CONF['path'] . 'plugins/calendarjp/templates');
 $cal_templates->set_file (array (
         'calendar'    => 'calendar' . ($ja ? '_ja' : '') . '.thtml',
         'week'        => 'calendarweek.thtml',
@@ -919,10 +909,6 @@ $cal_templates->set_file (array (
         'addevent'    => 'addeventoption.thtml'
         ));
 
-$cal_templates->set_var ('xhtml', XHTML);
-$cal_templates->set_var ('site_url', $_CONF['site_url']);
-$cal_templates->set_var ('site_admin_url', $_CONF['site_admin_url']);
-$cal_templates->set_var ('layout_url', $_CONF['layout_url']);
 $cal_templates->set_var ('mode', $mode);
 if ($mode == 'personal') {
     $cal_templates->set_var ('start_block', COM_startBlock ($LANG_CALJP_2[12]));
@@ -1148,7 +1134,7 @@ $cal_templates->parse('add_event_option','addevent',true);
 $cal_templates->parse('output','calendar');
 $display .= $cal_templates->finish($cal_templates->get_var('output'));
 
-$display .= COM_siteFooter();
+$display = COM_createHTMLDocument($display, array('pagetitle' => $pagetitle));
 break;
 
 } // end switch
