@@ -2,13 +2,13 @@
 
 /* Reminder: always indent with 4 spaces (no tabs). */
 // +---------------------------------------------------------------------------+
-// | Geeklog Static Pages Plugin 1.5                                           |
+// | Static Pages Plugin 1.6                                                   |
 // +---------------------------------------------------------------------------+
 // | index.php                                                                 |
 // |                                                                           |
 // | This is the main page for the Geeklog Static Pages Plugin                 |
 // +---------------------------------------------------------------------------+
-// | Copyright (C) 2000-2008 by the following authors:                         |
+// | Copyright (C) 2000-2010 by the following authors:                         |
 // |                                                                           |
 // | Authors: Tony Bibbs       - tony AT tonybibbs DOT com                     |
 // |          Tom Willett      - twillett AT users DOT sourceforge DOT net     |
@@ -30,9 +30,17 @@
 // | Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.           |
 // |                                                                           |
 // +---------------------------------------------------------------------------+
-//
-// $Id: index.php,v 1.48 2008/06/20 15:12:36 dhaun Exp $
 
+/**
+* Display a Static Page
+*
+* @package StaticPages
+* @subpackage public_html
+*/
+
+/**
+* Geeklog common function library
+*/
 require_once '../lib-common.php';
 
 if (!in_array('staticpages', $_PLUGINS)) {
@@ -46,12 +54,20 @@ if (!in_array('staticpages', $_PLUGINS)) {
 COM_setArgNames(array('page', 'disp_mode'));
 $page = COM_applyFilter(COM_getArgument('page'));
 $display_mode = COM_applyFilter(COM_getArgument('disp_mode'));
+$query = '';
+if (isset($_REQUEST['query'])) {
+    $query = COM_applyfilter($_GET['query']);
+}
+
+TOPIC_getTopic('staticpages', $page);
 
 // from comments display refresh:
-if (isset($_POST['order'])) {
-    $comment_order = COM_applyFilter($_POST['order']);
-    $comment_mode  = COM_applyFilter($_POST['mode']);
-    $page = COM_applyFilter($_POST['id']);
+if (isset($_REQUEST['order'])) {
+    $comment_order = COM_applyFilter($_REQUEST['order']);
+    $comment_mode  = COM_applyFilter($_REQUEST['mode']);
+    if (isset($_REQUEST['cpage'])) {
+        $comment_page = COM_applyFilter($_REQUEST['cpage']);
+    }
     if ((strcasecmp($comment_order, 'ASC') != 0) &&
             (strcasecmp($comment_order, 'DESC') != 0)) {
         $comment_order = '';
@@ -59,14 +75,30 @@ if (isset($_POST['order'])) {
 } else {
     $comment_order = '';
     $comment_mode  = '';
+    $comment_page = 1;
 }
 
 if ($display_mode != 'print') {
     $display_mode = '';
 }
 
-$retval = SP_returnStaticpage($page, $display_mode, $comment_order, $comment_mode);
+$msg = 0;
+if (isset($_GET['msg'])) {
+    $msg = COM_applyFilter($_GET['msg'], true);
+    if ($msg <= 0) {
+        $msg = 0;
+    }
+}
 
-echo $retval;
+$retval = SP_returnStaticpage($page, $display_mode, $comment_order, $comment_mode, $comment_page, $msg, $query);
+
+if ($display_mode == 'print') {
+    header('Content-Type: text/html; charset=' . COM_getCharset());
+    if (! empty($_CONF['frame_options'])) {
+        header('X-FRAME-OPTIONS: ' . $_CONF['frame_options']);
+    }
+}
+
+COM_output($retval);
 
 ?>
